Module Name:    src
Committed By:   andvar
Date:           Sat Aug 21 11:55:26 UTC 2021

Modified Files:
        src/libexec/httpd: bozohttpd.c
        src/share/mk: bsd.lib.mk
        src/sys/arch/acorn32/podulebus: esc.c escvar.h sfas.c sfasvar.h
        src/sys/arch/atari/pci: pci_machdep.c
        src/sys/arch/mac68k/dev: pm_direct.c
        src/sys/arch/sgimips/conf: GENERIC32_IP12 GENERIC32_IP2x GENERIC32_IP3x
        src/sys/arch/sparc64/sparc64: autoconf.c
        src/sys/dev/dkwedge: dk.c
        src/sys/dev/i2c: si70xx.c
        src/sys/dev/ic: isp_target.c wd33c93.c
        src/sys/dev/ieee1394: fwohci.c
        src/sys/dev/usb: if_upgt.c if_upgtvar.h
        src/sys/net80211: ieee80211.c
        src/sys/sys: audioio.h
        src/tests/lib/libcurses: t_curses.sh
        src/usr.sbin/sysinst: disks.c

Log Message:
fix some more typos in comments/log messages, improve wording as well.


To generate a diff of this commit:
cvs rdiff -u -r1.132 -r1.133 src/libexec/httpd/bozohttpd.c
cvs rdiff -u -r1.384 -r1.385 src/share/mk/bsd.lib.mk
cvs rdiff -u -r1.33 -r1.34 src/sys/arch/acorn32/podulebus/esc.c
cvs rdiff -u -r1.9 -r1.10 src/sys/arch/acorn32/podulebus/escvar.h
cvs rdiff -u -r1.29 -r1.30 src/sys/arch/acorn32/podulebus/sfas.c
cvs rdiff -u -r1.8 -r1.9 src/sys/arch/acorn32/podulebus/sfasvar.h
cvs rdiff -u -r1.61 -r1.62 src/sys/arch/atari/pci/pci_machdep.c
cvs rdiff -u -r1.29 -r1.30 src/sys/arch/mac68k/dev/pm_direct.c
cvs rdiff -u -r1.40 -r1.41 src/sys/arch/sgimips/conf/GENERIC32_IP12
cvs rdiff -u -r1.121 -r1.122 src/sys/arch/sgimips/conf/GENERIC32_IP2x
cvs rdiff -u -r1.133 -r1.134 src/sys/arch/sgimips/conf/GENERIC32_IP3x
cvs rdiff -u -r1.234 -r1.235 src/sys/arch/sparc64/sparc64/autoconf.c
cvs rdiff -u -r1.106 -r1.107 src/sys/dev/dkwedge/dk.c
cvs rdiff -u -r1.7 -r1.8 src/sys/dev/i2c/si70xx.c
cvs rdiff -u -r1.35 -r1.36 src/sys/dev/ic/isp_target.c
cvs rdiff -u -r1.30 -r1.31 src/sys/dev/ic/wd33c93.c
cvs rdiff -u -r1.147 -r1.148 src/sys/dev/ieee1394/fwohci.c
cvs rdiff -u -r1.31 -r1.32 src/sys/dev/usb/if_upgt.c
cvs rdiff -u -r1.6 -r1.7 src/sys/dev/usb/if_upgtvar.h
cvs rdiff -u -r1.60 -r1.61 src/sys/net80211/ieee80211.c
cvs rdiff -u -r1.38 -r1.39 src/sys/sys/audioio.h
cvs rdiff -u -r1.23 -r1.24 src/tests/lib/libcurses/t_curses.sh
cvs rdiff -u -r1.75 -r1.76 src/usr.sbin/sysinst/disks.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/libexec/httpd/bozohttpd.c
diff -u src/libexec/httpd/bozohttpd.c:1.132 src/libexec/httpd/bozohttpd.c:1.133
--- src/libexec/httpd/bozohttpd.c:1.132	Wed May  5 07:41:48 2021
+++ src/libexec/httpd/bozohttpd.c	Sat Aug 21 11:55:24 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: bozohttpd.c,v 1.132 2021/05/05 07:41:48 mrg Exp $	*/
+/*	$NetBSD: bozohttpd.c,v 1.133 2021/08/21 11:55:24 andvar Exp $	*/
 
 /*	$eterna: bozohttpd.c,v 1.178 2011/11/18 09:21:15 mrg Exp $	*/
 
@@ -1459,7 +1459,7 @@ use_slashdir:
 
 /*
  * checks to see if this request has a valid .bzredirect file.  returns
- * 0 when no redirection happend, or 1 when handle_redirect() has been
+ * 0 when no redirection happened, or 1 when handle_redirect() has been
  * called, -1 on error.
  */
 static int

Index: src/share/mk/bsd.lib.mk
diff -u src/share/mk/bsd.lib.mk:1.384 src/share/mk/bsd.lib.mk:1.385
--- src/share/mk/bsd.lib.mk:1.384	Mon Nov  9 16:15:05 2020
+++ src/share/mk/bsd.lib.mk	Sat Aug 21 11:55:24 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: bsd.lib.mk,v 1.384 2020/11/09 16:15:05 christos Exp $
+#	$NetBSD: bsd.lib.mk,v 1.385 2021/08/21 11:55:24 andvar Exp $
 #	@(#)bsd.lib.mk	8.3 (Berkeley) 4/22/94
 
 .include <bsd.init.mk>
@@ -147,7 +147,7 @@ SHLIB_FULLVERSION=${SHLIB_MAJOR}
 # SHLIB_MAJOR, SHLIB_MINOR, SHLIB_TEENY: Major, minor, and teeny version
 #			numbers of shared library
 # SHLIB_SOVERSION:	version number to be compiled into a shared library
-#			via -soname. Usualy ${SHLIB_MAJOR} on ELF.
+#			via -soname. Usually ${SHLIB_MAJOR} on ELF.
 #			NetBSD/pmax used to use ${SHLIB_MAJOR}[.${SHLIB_MINOR}
 #			[.${SHLIB_TEENY}]]
 # SHLIB_SHFLAGS:	Flags to tell ${LD} to emit shared library.

Index: src/sys/arch/acorn32/podulebus/escvar.h
diff -u src/sys/arch/acorn32/podulebus/escvar.h:1.9 src/sys/arch/acorn32/podulebus/escvar.h:1.10
--- src/sys/arch/acorn32/podulebus/escvar.h:1.9	Wed Jul 22 01:24:39 2020
+++ src/sys/arch/acorn32/podulebus/escvar.h	Sat Aug 21 11:55:24 2021
@@ -1,4 +1,4 @@
-/* $NetBSD: escvar.h,v 1.9 2020/07/22 01:24:39 msaitoh Exp $ */
+/* $NetBSD: escvar.h,v 1.10 2021/08/21 11:55:24 andvar Exp $ */
 
 /*
  * Copyright (c) 1995 Daniel Widenfalk
@@ -129,7 +129,7 @@ struct nexus {
 #define ESC_NS_DISCONNECTED	9	/* We are disconnected */
 #define ESC_NS_RESELECTED	10	/* We was reselected */
 #define ESC_NS_DONE		11	/* Done. Prephsase to FINISHED */
-#define ESC_NS_FINISHED		12	/* Realy done. Call scsi_done */
+#define ESC_NS_FINISHED		12	/* Really done. Call scsi_done */
 #define ESC_NS_RESET		13	/* We are resetting this unit */
 
 /* SCSI nexus flags */

Index: src/sys/arch/acorn32/podulebus/sfasvar.h
diff -u src/sys/arch/acorn32/podulebus/sfasvar.h:1.8 src/sys/arch/acorn32/podulebus/sfasvar.h:1.9
--- src/sys/arch/acorn32/podulebus/sfasvar.h:1.8	Wed Jul 22 01:24:39 2020
+++ src/sys/arch/acorn32/podulebus/sfasvar.h	Sat Aug 21 11:55:24 2021
@@ -1,4 +1,4 @@
-/* $NetBSD: sfasvar.h,v 1.8 2020/07/22 01:24:39 msaitoh Exp $ */
+/* $NetBSD: sfasvar.h,v 1.9 2021/08/21 11:55:24 andvar Exp $ */
 
 /*
  * Copyright (c) 1995 Daniel Widenfalk
@@ -128,7 +128,7 @@ struct nexus {
 #define SFAS_NS_DISCONNECTED	9	/* We are disconnected */
 #define SFAS_NS_RESELECTED	10	/* We was reselected */
 #define SFAS_NS_DONE		11	/* Done. Prephsase to FINISHED */
-#define SFAS_NS_FINISHED	12	/* Realy done. Call scsi_done */
+#define SFAS_NS_FINISHED	12	/* Really done. Call scsi_done */
 #define SFAS_NS_RESET		13	/* We are resetting this unit */
 
 /* SCSI nexus flags */

Index: src/sys/arch/atari/pci/pci_machdep.c
diff -u src/sys/arch/atari/pci/pci_machdep.c:1.61 src/sys/arch/atari/pci/pci_machdep.c:1.62
--- src/sys/arch/atari/pci/pci_machdep.c:1.61	Sat Aug  7 16:18:46 2021
+++ src/sys/arch/atari/pci/pci_machdep.c	Sat Aug 21 11:55:24 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: pci_machdep.c,v 1.61 2021/08/07 16:18:46 thorpej Exp $	*/
+/*	$NetBSD: pci_machdep.c,v 1.62 2021/08/21 11:55:24 andvar Exp $	*/
 
 /*
  * Copyright (c) 1996 Leo Weppelman.  All rights reserved.
@@ -32,7 +32,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: pci_machdep.c,v 1.61 2021/08/07 16:18:46 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pci_machdep.c,v 1.62 2021/08/21 11:55:24 andvar Exp $");
 
 #include "opt_mbtype.h"
 
@@ -75,7 +75,7 @@ __KERNEL_RCSID(0, "$NetBSD: pci_machdep.
 					    I/O addresses up to 0xffff) */
 
 /*
- * PCI memory and IO should be aligned acording to this masks
+ * PCI memory and IO should be aligned according to these masks
  */
 #define PCI_MACHDEP_IO_ALIGN_MASK	0xffffff00
 #define PCI_MACHDEP_MEM_ALIGN_MASK	0xfffff000

Index: src/sys/arch/mac68k/dev/pm_direct.c
diff -u src/sys/arch/mac68k/dev/pm_direct.c:1.29 src/sys/arch/mac68k/dev/pm_direct.c:1.30
--- src/sys/arch/mac68k/dev/pm_direct.c:1.29	Fri Oct 25 20:49:38 2013
+++ src/sys/arch/mac68k/dev/pm_direct.c	Sat Aug 21 11:55:24 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: pm_direct.c,v 1.29 2013/10/25 20:49:38 martin Exp $	*/
+/*	$NetBSD: pm_direct.c,v 1.30 2021/08/21 11:55:24 andvar Exp $	*/
 
 /*
  * Copyright (C) 1997 Takashi Hamada
@@ -32,7 +32,7 @@
 /* From: pm_direct.c 1.3 03/18/98 Takashi Hamada */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: pm_direct.c,v 1.29 2013/10/25 20:49:38 martin Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pm_direct.c,v 1.30 2021/08/21 11:55:24 andvar Exp $");
 
 #include "opt_adb.h"
 
@@ -549,7 +549,7 @@ pm_intr_pm1(void *arg)
 
 	PM_VIA_CLR_INTR();				/* clear VIA1 interrupt */
 
-	/* ask PM what happend */
+	/* ask PM what happened */
 	pmdata.command = 0x78;
 	pmdata.num_data = 0;
 	pmdata.data[0] = pmdata.data[1] = 0;
@@ -809,7 +809,7 @@ pm_intr_pm2(void *arg)
 	s = splhigh();
 
 	PM_VIA_CLR_INTR();			/* clear VIA1 interrupt */
-						/* ask PM what happend */
+						/* ask PM what happened */
 	pmdata.command = 0x78;
 	pmdata.num_data = 0;
 	pmdata.s_buf = &pmdata.data[2];

Index: src/sys/arch/sgimips/conf/GENERIC32_IP12
diff -u src/sys/arch/sgimips/conf/GENERIC32_IP12:1.40 src/sys/arch/sgimips/conf/GENERIC32_IP12:1.41
--- src/sys/arch/sgimips/conf/GENERIC32_IP12:1.40	Thu Jan 21 06:51:56 2021
+++ src/sys/arch/sgimips/conf/GENERIC32_IP12	Sat Aug 21 11:55:24 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: GENERIC32_IP12,v 1.40 2021/01/21 06:51:56 nia Exp $
+#	$NetBSD: GENERIC32_IP12,v 1.41 2021/08/21 11:55:24 andvar Exp $
 #
 # GENERIC32_IP12 machine description file
 # 
@@ -32,7 +32,7 @@ makeoptions	TEXTADDR=0x80002000	# entry 
 
 options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
 
-#ident		"GENERIC32-IP2x-$Revision: 1.40 $"
+#ident		"GENERIC32-IP2x-$Revision: 1.41 $"
 
 maxusers	32
 
@@ -48,7 +48,7 @@ options 	BLINK		# blinkenlitzen
 # Standard system options
 #options 	INSECURE	# disable kernel security levels
 
-#options 	NTP		# NTP phase/frequence locked loop
+#options 	NTP		# NTP phase/frequency locked loop
 options 	KTRACE		# system call tracing via ktrace(1)
 
 options 	SYSVMSG		# System V message queues

Index: src/sys/arch/sgimips/conf/GENERIC32_IP2x
diff -u src/sys/arch/sgimips/conf/GENERIC32_IP2x:1.121 src/sys/arch/sgimips/conf/GENERIC32_IP2x:1.122
--- src/sys/arch/sgimips/conf/GENERIC32_IP2x:1.121	Sun Sep 27 13:48:54 2020
+++ src/sys/arch/sgimips/conf/GENERIC32_IP2x	Sat Aug 21 11:55:24 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: GENERIC32_IP2x,v 1.121 2020/09/27 13:48:54 roy Exp $
+#	$NetBSD: GENERIC32_IP2x,v 1.122 2021/08/21 11:55:24 andvar Exp $
 #
 # GENERIC32_IP2x machine description file
 # 
@@ -29,7 +29,7 @@ makeoptions	TEXTADDR=0x88069000	# entry 
 
 options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
 
-#ident		"GENERIC32-IP2x-$Revision: 1.121 $"
+#ident		"GENERIC32-IP2x-$Revision: 1.122 $"
 
 maxusers	32
 
@@ -48,7 +48,7 @@ makeoptions	WANT_ECOFF="yes"	# Create an
 # Standard system options
 #options 	INSECURE	# disable kernel security levels
 
-#options 	NTP		# NTP phase/frequence locked loop
+#options 	NTP		# NTP phase/frequency locked loop
 options 	KTRACE		# system call tracing via ktrace(1)
 
 options 	SYSVMSG		# System V message queues

Index: src/sys/arch/sgimips/conf/GENERIC32_IP3x
diff -u src/sys/arch/sgimips/conf/GENERIC32_IP3x:1.133 src/sys/arch/sgimips/conf/GENERIC32_IP3x:1.134
--- src/sys/arch/sgimips/conf/GENERIC32_IP3x:1.133	Sun Sep 27 13:48:54 2020
+++ src/sys/arch/sgimips/conf/GENERIC32_IP3x	Sat Aug 21 11:55:24 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: GENERIC32_IP3x,v 1.133 2020/09/27 13:48:54 roy Exp $
+#	$NetBSD: GENERIC32_IP3x,v 1.134 2021/08/21 11:55:24 andvar Exp $
 #
 # GENERIC32_IP3x machine description file
 # 
@@ -28,7 +28,7 @@ makeoptions	TEXTADDR="0x80069000"	# entr
 
 options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
 
-#ident		"GENERIC32_IP3x-$Revision: 1.133 $"
+#ident		"GENERIC32_IP3x-$Revision: 1.134 $"
 
 maxusers	32
 
@@ -41,7 +41,7 @@ makeoptions	CPUFLAGS="-march=mips3 -mtun
 # Standard system options
 #options 	INSECURE	# disable kernel security levels
 
-#options 	NTP		# NTP phase/frequence locked loop
+#options 	NTP		# NTP phase/frequency locked loop
 options 	KTRACE		# system call tracing via ktrace(1)
 
 options 	SYSVMSG		# System V message queues

Index: src/sys/arch/sparc64/sparc64/autoconf.c
diff -u src/sys/arch/sparc64/sparc64/autoconf.c:1.234 src/sys/arch/sparc64/sparc64/autoconf.c:1.235
--- src/sys/arch/sparc64/sparc64/autoconf.c:1.234	Sat Aug  7 16:19:06 2021
+++ src/sys/arch/sparc64/sparc64/autoconf.c	Sat Aug 21 11:55:25 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: autoconf.c,v 1.234 2021/08/07 16:19:06 thorpej Exp $ */
+/*	$NetBSD: autoconf.c,v 1.235 2021/08/21 11:55:25 andvar Exp $ */
 
 /*
  * Copyright (c) 1996
@@ -48,7 +48,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: autoconf.c,v 1.234 2021/08/07 16:19:06 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: autoconf.c,v 1.235 2021/08/21 11:55:25 andvar Exp $");
 
 #include "opt_ddb.h"
 #include "opt_kgdb.h"
@@ -289,7 +289,7 @@ bootstrap(void *o0, void *bootargs, void
 	extern void OF_sym2val32(void *);
 	extern struct consdev consdev_prom;
 
-	/* Save OpenFrimware entry point */
+	/* Save OpenFirmware entry point */
 	romp   = ofw;
 	romtba = get_romtba();
 
@@ -924,7 +924,7 @@ dev_path_drive_match(device_t dev, int c
 		/*
 		 * Note: "child" here is == ofbootpackage (s.a.), which
 		 * may be completely wrong for the device we are checking,
-		 * what we realy do here is to match "target" and "lun".
+		 * what we really do here is to match "target" and "lun".
 		 */
 		if (wwn)
 			snprintf(buf, sizeof(buf), "%s@w%016" PRIx64 ",%d",

Index: src/sys/dev/dkwedge/dk.c
diff -u src/sys/dev/dkwedge/dk.c:1.106 src/sys/dev/dkwedge/dk.c:1.107
--- src/sys/dev/dkwedge/dk.c:1.106	Wed Aug  4 21:44:41 2021
+++ src/sys/dev/dkwedge/dk.c	Sat Aug 21 11:55:25 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: dk.c,v 1.106 2021/08/04 21:44:41 mlelstv Exp $	*/
+/*	$NetBSD: dk.c,v 1.107 2021/08/21 11:55:25 andvar Exp $	*/
 
 /*-
  * Copyright (c) 2004, 2005, 2006, 2007 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: dk.c,v 1.106 2021/08/04 21:44:41 mlelstv Exp $");
+__KERNEL_RCSID(0, "$NetBSD: dk.c,v 1.107 2021/08/21 11:55:25 andvar Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_dkwedge.h"
@@ -362,7 +362,7 @@ dkwedge_add(struct dkwedge_info *dkw)
 
 	/*
 	 * Wedge will be added; increment the wedge count for the parent.
-	 * Only allow this to happend if RAW_PART is the only thing open.
+	 * Only allow this to happen if RAW_PART is the only thing open.
 	 */
 	mutex_enter(&pdk->dk_openlock);
 	if (pdk->dk_openmask & ~(1 << RAW_PART))

Index: src/sys/dev/i2c/si70xx.c
diff -u src/sys/dev/i2c/si70xx.c:1.7 src/sys/dev/i2c/si70xx.c:1.8
--- src/sys/dev/i2c/si70xx.c:1.7	Tue Jun 15 04:39:49 2021
+++ src/sys/dev/i2c/si70xx.c	Sat Aug 21 11:55:25 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: si70xx.c,v 1.7 2021/06/15 04:39:49 mlelstv Exp $	*/
+/*	$NetBSD: si70xx.c,v 1.8 2021/08/21 11:55:25 andvar Exp $	*/
 
 /*
  * Copyright (c) 2017 Brad Spencer <b...@anduin.eldar.org>
@@ -17,7 +17,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: si70xx.c,v 1.7 2021/06/15 04:39:49 mlelstv Exp $");
+__KERNEL_RCSID(0, "$NetBSD: si70xx.c,v 1.8 2021/08/21 11:55:25 andvar Exp $");
 
 /*
   Driver for the Silicon Labs SI7013/SI7020/SI7021
@@ -687,7 +687,7 @@ si70xx_attach(device_t parent, device_t 
 	    buf, 8);
 
 	if (error) {
-		aprint_error_dev(self, "Failed to read firware version: %d\n",
+		aprint_error_dev(self, "Failed to read firmware version: %d\n",
 		    error);
 		ecount++;
 	}

Index: src/sys/dev/ic/isp_target.c
diff -u src/sys/dev/ic/isp_target.c:1.35 src/sys/dev/ic/isp_target.c:1.36
--- src/sys/dev/ic/isp_target.c:1.35	Mon Sep  3 16:29:31 2018
+++ src/sys/dev/ic/isp_target.c	Sat Aug 21 11:55:25 2021
@@ -1,4 +1,4 @@
--/* $NetBSD: isp_target.c,v 1.35 2018/09/03 16:29:31 riastradh Exp $ */
+-/* $NetBSD: isp_target.c,v 1.36 2021/08/21 11:55:25 andvar Exp $ */
 /*-
  *  Copyright (c) 1997-2008 by Matthew Jacob
  *  All rights reserved.
@@ -65,7 +65,7 @@
 
 #ifdef	__NetBSD__
 #include <sys/cdefs.h> 
-__KERNEL_RCSID(0, "$NetBSD: isp_target.c,v 1.35 2018/09/03 16:29:31 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: isp_target.c,v 1.36 2021/08/21 11:55:25 andvar Exp $");
 #include <dev/ic/isp_netbsd.h>
 #endif
 #ifdef	__FreeBSD__
@@ -1256,7 +1256,7 @@ isp_handle_atio(ispsoftc_t *isp, at_entr
 	 * The firmware status (except for the QLTM_SVALID bit) indicates
 	 * why this ATIO was sent to us.
 	 *
-	 * If QLTM_SVALID is set, the firware has recommended Sense Data.
+	 * If QLTM_SVALID is set, the firmware has recommended Sense Data.
 	 *
 	 * If the DISCONNECTS DISABLED bit is set in the flags field,
 	 * we're still connected on the SCSI bus - i.e. the initiator
@@ -1342,7 +1342,7 @@ isp_handle_atio2(ispsoftc_t *isp, at2_en
 	 * The firmware status (except for the QLTM_SVALID bit) indicates
 	 * why this ATIO was sent to us.
 	 *
-	 * If QLTM_SVALID is set, the firware has recommended Sense Data.
+	 * If QLTM_SVALID is set, the firmware has recommended Sense Data.
 	 *
 	 * If the DISCONNECTS DISABLED bit is set in the flags field,
 	 * we're still connected on the SCSI bus - i.e. the initiator

Index: src/sys/dev/ic/wd33c93.c
diff -u src/sys/dev/ic/wd33c93.c:1.30 src/sys/dev/ic/wd33c93.c:1.31
--- src/sys/dev/ic/wd33c93.c:1.30	Sat Aug  7 16:19:12 2021
+++ src/sys/dev/ic/wd33c93.c	Sat Aug 21 11:55:25 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: wd33c93.c,v 1.30 2021/08/07 16:19:12 thorpej Exp $	*/
+/*	$NetBSD: wd33c93.c,v 1.31 2021/08/21 11:55:25 andvar Exp $	*/
 
 /*
  * Copyright (c) 1990 The Regents of the University of California.
@@ -79,7 +79,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: wd33c93.c,v 1.30 2021/08/07 16:19:12 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: wd33c93.c,v 1.31 2021/08/21 11:55:25 andvar Exp $");
 
 #include "opt_ddb.h"
 
@@ -2140,7 +2140,7 @@ wd33c93_nextstate(struct wd33c93_softc *
 
 	default:
 	abort:
-		/* Something unexpected happend -- deal with it. */
+		/* Something unexpected happened -- deal with it. */
 		printf("next: aborting asr 0x%02x csr 0x%02x\n", asr, csr);
 
 #ifdef DDB

Index: src/sys/dev/ieee1394/fwohci.c
diff -u src/sys/dev/ieee1394/fwohci.c:1.147 src/sys/dev/ieee1394/fwohci.c:1.148
--- src/sys/dev/ieee1394/fwohci.c:1.147	Sat Aug 21 09:59:46 2021
+++ src/sys/dev/ieee1394/fwohci.c	Sat Aug 21 11:55:25 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: fwohci.c,v 1.147 2021/08/21 09:59:46 andvar Exp $	*/
+/*	$NetBSD: fwohci.c,v 1.148 2021/08/21 11:55:25 andvar Exp $	*/
 
 /*-
  * Copyright (c) 2003 Hidetoshi Shimokawa
@@ -37,7 +37,7 @@
  *
  */
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: fwohci.c,v 1.147 2021/08/21 09:59:46 andvar Exp $");
+__KERNEL_RCSID(0, "$NetBSD: fwohci.c,v 1.148 2021/08/21 11:55:25 andvar Exp $");
 
 #include <sys/param.h>
 #include <sys/atomic.h>
@@ -2271,7 +2271,7 @@ fwohci_rbuf_update(struct fwohci_softc *
 		else
 			/* XXX */
 			aprint_error_dev(fc->dev,
-			    "fwohci_rbuf_update: this shouldn't happend\n");
+			    "fwohci_rbuf_update: this shouldn't happen\n");
 
 		STAILQ_REMOVE_HEAD(&ir->stdma, link);
 		STAILQ_INSERT_TAIL(&ir->stvalid, chunk, link);

Index: src/sys/dev/usb/if_upgt.c
diff -u src/sys/dev/usb/if_upgt.c:1.31 src/sys/dev/usb/if_upgt.c:1.32
--- src/sys/dev/usb/if_upgt.c:1.31	Sun Mar 15 23:04:51 2020
+++ src/sys/dev/usb/if_upgt.c	Sat Aug 21 11:55:25 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_upgt.c,v 1.31 2020/03/15 23:04:51 thorpej Exp $	*/
+/*	$NetBSD: if_upgt.c,v 1.32 2021/08/21 11:55:25 andvar Exp $	*/
 /*	$OpenBSD: if_upgt.c,v 1.49 2010/04/20 22:05:43 tedu Exp $ */
 
 /*
@@ -18,7 +18,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_upgt.c,v 1.31 2020/03/15 23:04:51 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_upgt.c,v 1.32 2021/08/21 11:55:25 andvar Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_usb.h"
@@ -1172,7 +1172,7 @@ upgt_eeprom_parse_freq3(struct upgt_soft
 
 		sc->sc_eeprom_freq3[channel] = freq3[i];
 
-		DPRINTF(2, "%s: frequence=%d, channel=%d\n",
+		DPRINTF(2, "%s: frequency=%d, channel=%d\n",
 		    device_xname(sc->sc_dev),
 		    le16toh(sc->sc_eeprom_freq3[channel].freq), channel);
 	}
@@ -1212,7 +1212,7 @@ upgt_eeprom_parse_freq4(struct upgt_soft
 			sc->sc_eeprom_freq4[channel][j].pad = 0;
 		}
 
-		DPRINTF(2, "%s: frequence=%d, channel=%d\n",
+		DPRINTF(2, "%s: frequency=%d, channel=%d\n",
 		    device_xname(sc->sc_dev),
 		    le16toh(freq4_1[i].freq), channel);
 	}
@@ -1236,7 +1236,7 @@ upgt_eeprom_parse_freq6(struct upgt_soft
 
 		sc->sc_eeprom_freq6[channel] = freq6[i];
 
-		DPRINTF(2, "%s: frequence=%d, channel=%d\n",
+		DPRINTF(2, "%s: frequency=%d, channel=%d\n",
 		    device_xname(sc->sc_dev),
 		    le16toh(sc->sc_eeprom_freq6[channel].freq), channel);
 	}

Index: src/sys/dev/usb/if_upgtvar.h
diff -u src/sys/dev/usb/if_upgtvar.h:1.6 src/sys/dev/usb/if_upgtvar.h:1.7
--- src/sys/dev/usb/if_upgtvar.h:1.6	Sun Mar 15 23:04:51 2020
+++ src/sys/dev/usb/if_upgtvar.h	Sat Aug 21 11:55:25 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_upgtvar.h,v 1.6 2020/03/15 23:04:51 thorpej Exp $	*/
+/*	$NetBSD: if_upgtvar.h,v 1.7 2021/08/21 11:55:25 andvar Exp $	*/
 /*	$OpenBSD: if_upgtvar.h,v 1.15 2009/08/10 20:02:19 deraadt Exp $ */
 
 /*
@@ -270,19 +270,19 @@ struct upgt_lmac_filter {
 	uint32_t			unknown4;
 } __packed;
 
-/* frequence 3 data */
+/* frequency 3 data */
 struct upgt_lmac_freq3 {
 	uint16_t			freq;
 	uint8_t				data[6];
 } __packed;
 
-/* frequence 4 data */
+/* frequency 4 data */
 struct upgt_lmac_freq4 {
 	struct upgt_eeprom_freq4_2	cmd;
 	uint8_t				pad;
 };
 
-/* frequence 6 data */
+/* frequency 6 data */
 struct upgt_lmac_freq6 {
 	uint16_t			freq;
 	uint8_t				data[8];

Index: src/sys/net80211/ieee80211.c
diff -u src/sys/net80211/ieee80211.c:1.60 src/sys/net80211/ieee80211.c:1.61
--- src/sys/net80211/ieee80211.c:1.60	Tue Oct  6 23:51:05 2020
+++ src/sys/net80211/ieee80211.c	Sat Aug 21 11:55:25 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: ieee80211.c,v 1.60 2020/10/06 23:51:05 roy Exp $	*/
+/*	$NetBSD: ieee80211.c,v 1.61 2021/08/21 11:55:25 andvar Exp $	*/
 /*-
  * Copyright (c) 2001 Atsushi Onoe
  * Copyright (c) 2002-2005 Sam Leffler, Errno Consulting
@@ -36,7 +36,7 @@
 __FBSDID("$FreeBSD: src/sys/net80211/ieee80211.c,v 1.22 2005/08/10 16:22:29 sam Exp $");
 #endif
 #ifdef __NetBSD__
-__KERNEL_RCSID(0, "$NetBSD: ieee80211.c,v 1.60 2020/10/06 23:51:05 roy Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ieee80211.c,v 1.61 2021/08/21 11:55:25 andvar Exp $");
 #endif
 
 /*
@@ -1048,7 +1048,7 @@ ieee80211_rate2media(struct ieee80211com
 		{  72 | IFM_IEEE80211_11G, IFM_IEEE80211_OFDM36 },
 		{  96 | IFM_IEEE80211_11G, IFM_IEEE80211_OFDM48 },
 		{ 108 | IFM_IEEE80211_11G, IFM_IEEE80211_OFDM54 },
-		/* NB: OFDM72 doesn't realy exist so we don't handle it */
+		/* NB: OFDM72 doesn't really exist so we don't handle it */
 	};
 	u_int mask, i;
 

Index: src/sys/sys/audioio.h
diff -u src/sys/sys/audioio.h:1.38 src/sys/sys/audioio.h:1.39
--- src/sys/sys/audioio.h:1.38	Wed May  8 13:40:19 2019
+++ src/sys/sys/audioio.h	Sat Aug 21 11:55:25 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: audioio.h,v 1.38 2019/05/08 13:40:19 isaki Exp $	*/
+/*	$NetBSD: audioio.h,v 1.39 2021/08/21 11:55:25 andvar Exp $	*/
 
 /*
  * Copyright (c) 1991-1993 Regents of the University of California.
@@ -183,7 +183,7 @@ struct audio_format {
 
 	/**
 	 * The bit size of one sample.
-	 * It must be >= validbits, and is usualy a multiple of 8.
+	 * It must be >= validbits, and is usually a multiple of 8.
 	 */
 	u_int precision;
 

Index: src/tests/lib/libcurses/t_curses.sh
diff -u src/tests/lib/libcurses/t_curses.sh:1.23 src/tests/lib/libcurses/t_curses.sh:1.24
--- src/tests/lib/libcurses/t_curses.sh:1.23	Sat Feb 13 08:00:07 2021
+++ src/tests/lib/libcurses/t_curses.sh	Sat Aug 21 11:55:26 2021
@@ -1200,7 +1200,7 @@ wecho_wchar_body()
 atf_test_case halfdelay
 halfdelay_head()
 {
-    atf_set "descr" "Tests seting the input mode to half delay"
+    atf_set "descr" "Tests setting the input mode to half delay"
 }
 halfdelay_body()
 {

Index: src/usr.sbin/sysinst/disks.c
diff -u src/usr.sbin/sysinst/disks.c:1.75 src/usr.sbin/sysinst/disks.c:1.76
--- src/usr.sbin/sysinst/disks.c:1.75	Thu Aug 12 09:33:59 2021
+++ src/usr.sbin/sysinst/disks.c	Sat Aug 21 11:55:26 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: disks.c,v 1.75 2021/08/12 09:33:59 martin Exp $ */
+/*	$NetBSD: disks.c,v 1.76 2021/08/21 11:55:26 andvar Exp $ */
 
 /*
  * Copyright 1997 Piermont Information Systems Inc.
@@ -543,7 +543,7 @@ is_partitionable_device(const char *dev)
  * Multi-purpose helper function:
  * iterate all known disks, invoke a callback for each.
  * Stop iteration when the callback returns false.
- * Return true when iteration actually happend, false on error.
+ * Return true when iteration actually happened, false on error.
  */
 bool
 enumerate_disks(void *state, bool (*func)(void *state, const char *dev))

Reply via email to
Index: src/sys/arch/acorn32/podulebus/esc.c
diff -u src/sys/arch/acorn32/podulebus/esc.c:1.33 src/sys/arch/acorn32/podulebus/esc.c:1.34
--- src/sys/arch/acorn32/podulebus/esc.c:1.33	Wed Jul 22 01:24:39 2020
+++ src/sys/arch/acorn32/podulebus/esc.c	Sat Aug 21 11:55:24 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: esc.c,v 1.33 2020/07/22 01:24:39 msaitoh Exp $	*/
+/*	$NetBSD: esc.c,v 1.34 2021/08/21 11:55:24 andvar Exp $	*/
 
 /*
  * Copyright (c) 1990 The Regents of the University of California.
@@ -86,7 +86,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: esc.c,v 1.33 2020/07/22 01:24:39 msaitoh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: esc.c,v 1.34 2021/08/21 11:55:24 andvar Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -209,7 +209,7 @@ escinitialize(struct esc_softc *dev)
 	if (dev->sc_clock_freq <= 40)
 		dev->sc_clock_conv_fact = 2+((dev->sc_clock_freq-10)/5);
 	else
-		panic("escinitialize: Clock frequence too high");
+		panic("escinitialize: Clock frequency too high");
 
 /* Setup and save the basic configuration registers */
 	dev->sc_config1 = (dev->sc_host_id & ESC_CFG1_BUS_ID_MASK);
@@ -330,7 +330,7 @@ esc_donextcmd(struct esc_softc *dev, str
  * select the unit during splbio. We then cycle through the generated
  * interrupts until the interrupt routine signals that the unit has
  * acknowledged the reset. After that we have to wait a reset to select
- * delay before anything else can happend.
+ * delay before anything else can happen.
  */
 	if (pendp->xs->xs_control & XS_CTL_RESET) {
 		struct nexus	*nexus;
@@ -774,7 +774,7 @@ esc_arbitate_target(struct esc_softc *de
 	int		 s;
 
 /*
- * This is realy simple. Raise interrupt level to splbio. Grab the nexus and
+ * This is really simple. Raise interrupt level to splbio. Grab the nexus and
  * leave.
  */
 	nexus = &dev->sc_nexus[target];
@@ -859,8 +859,8 @@ esc_setup_nexus(struct esc_softc *dev, s
 	} else if (sync && !(nexus->flags & ESC_NF_SYNC_TESTED)) {
 		/*
 		 * If the scsi unit is not set to synch transfer and we want
 		 * that, we have to negotiate. This should realy base the
 		 * period on the clock frequence rather than just check if
 		 * >25 MHz
 		 */
 
@@ -1248,7 +1248,7 @@ esc_midaction(struct esc_softc *dev, esc
 			nexus->status = -1;
 
 		/*
-		 * Preload the command complete message. Handeled in
+		 * Preload the command complete message. Handled in
 		 * esc_postaction.
 		 */
 		dev->sc_msg_in[0] = msg;
@@ -1369,7 +1369,7 @@ esc_postaction(struct esc_softc *dev, es
 	case ESC_PHASE_MESSAGE_OUT:
 		/*
 		 * Either the scsi unit wants us to send a message or we have
-		 * asked for it by seting the ATN bit.
+		 * asked for it by setting the ATN bit.
 		 */
 		nexus->state = ESC_NS_MSG_OUT;
 
@@ -1523,7 +1523,7 @@ esc_postaction(struct esc_softc *dev, es
 					/*
 					 * Hmmm, it seems that the scsi unit
 					 * initiated sync negotiation, so lets
-					 * reply acording to scsi-2 standard.
+					 * reply according to scsi-2 standard.
 					 */
 					if (!(nexus->flags& ESC_NF_SDTR_SENT))
 					{
@@ -1550,7 +1550,7 @@ esc_postaction(struct esc_softc *dev, es
 				case 0x02: /* EXTENDED IDENTIFY (SCSI-1) */
 				case 0x03: /* WIDE DATA TRANSFER REQUEST */
 			        default:
-					/* Reject any unhandeled messages. */
+					/* Reject any unhandled messages. */
 
 					dev->sc_msg_out[0] = 0x07;
 					dev->sc_msg_out_len = 1;
@@ -1561,7 +1561,7 @@ esc_postaction(struct esc_softc *dev, es
 				break;
 
 			default:
-				/* Reject any unhandeled messages. */
+				/* Reject any unhandled messages. */
 
 				dev->sc_msg_out[0] = 0x07;
 				dev->sc_msg_out_len = 1;
@@ -859,8 +859,8 @@ esc_setup_nexus(struct esc_softc *dev, s
 		/*
 		 * If the scsi unit is not set to synch transfer and we want
-		 * that, we have to negotiate. This should realy base the
-		 * period on the clock frequence rather than just check if
+		 * that, we have to negotiate. This should really base the
+		 * period on the clock frequency rather than just check if
 		 * >25 MHz
 		 */

Index: src/sys/arch/acorn32/podulebus/sfas.c
diff -u src/sys/arch/acorn32/podulebus/sfas.c:1.29 src/sys/arch/acorn32/podulebus/sfas.c:1.30
--- src/sys/arch/acorn32/podulebus/sfas.c:1.29	Wed Jul 22 01:24:39 2020
+++ src/sys/arch/acorn32/podulebus/sfas.c	Sat Aug 21 11:55:24 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: sfas.c,v 1.29 2020/07/22 01:24:39 msaitoh Exp $	*/
+/*	$NetBSD: sfas.c,v 1.30 2021/08/21 11:55:24 andvar Exp $	*/
 
 /*
  * Copyright (c) 1990 The Regents of the University of California.
@@ -82,7 +82,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: sfas.c,v 1.29 2020/07/22 01:24:39 msaitoh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: sfas.c,v 1.30 2021/08/21 11:55:24 andvar Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -202,7 +202,7 @@ sfasinitialize(struct sfas_softc *dev)
 	if (dev->sc_clock_freq <= 40)
 		dev->sc_clock_conv_fact = 2+((dev->sc_clock_freq-10)/5);
 	else
-		panic("sfasinitialize: Clock frequence too high");
+		panic("sfasinitialize: Clock frequency too high");
 
 /* Setup and save the basic configuration registers */
 	dev->sc_config1 = (dev->sc_host_id & SFAS_CFG1_BUS_ID_MASK);
@@ -326,7 +326,7 @@ sfas_donextcmd(struct sfas_softc *dev, s
  * select the unit during splbio. We then cycle through the generated
  * interrupts until the interrupt routine signals that the unit has
  * acknowledged the reset. After that we have to wait a reset to select
- * delay before anything else can happend.
+ * delay before anything else can happen.
  */
 	if (pendp->xs->xs_control & XS_CTL_RESET) {
 		struct nexus	*nexus;
@@ -695,7 +695,7 @@ sfas_arbitate_target(struct sfas_softc *
 	int		 s;
 
 /*
- * This is realy simple. Raise interrupt level to splbio. Grab the nexus and
+ * This is really simple. Raise interrupt level to splbio. Grab the nexus and
  * leave.
  */
 	nexus = &dev->sc_nexus[target];
@@ -780,8 +780,8 @@ sfas_setup_nexus(struct sfas_softc *dev,
 	} else if (sync && !(nexus->flags & SFAS_NF_SYNC_TESTED)) {
 		/*
 		 * If the scsi unit is not set to synch transfer and we want
 		 * that, we have to negotiate. This should realy base the
 		 * period on the clock frequence rather than just check if
 		 * >25 MHz
 		 */
 
@@ -1169,7 +1169,7 @@ sfas_midaction(struct sfas_softc *dev, s
 			nexus->status = -1;
 
 		/*
-		 * Preload the command complete message. Handeled in
+		 * Preload the command complete message. Handled in
 		 * sfas_postaction.
 		 */
 		dev->sc_msg_in[0] = msg;
@@ -1288,7 +1288,7 @@ sfas_postaction(struct sfas_softc *dev, 
 	case SFAS_PHASE_MESSAGE_OUT:
 		/*
 		 * Either the scsi unit wants us to send a message or we have
-		 * asked for it by seting the ATN bit.
+		 * asked for it by setting the ATN bit.
 		 */
 		nexus->state = SFAS_NS_MSG_OUT;
 
@@ -1442,7 +1442,7 @@ sfas_postaction(struct sfas_softc *dev, 
 					/*
 					 * Hmmm, it seems that the scsi unit
 					 * initiated sync negotiation, so lets
-					 * reply acording to scsi-2 standard.
+					 * reply according to scsi-2 standard.
 					 */
 					if (!(nexus->flags& SFAS_NF_SDTR_SENT))
 					{
@@ -1469,7 +1469,7 @@ sfas_postaction(struct sfas_softc *dev, 
 				case 0x02: /* EXTENDED IDENTIFY (SCSI-1) */
 				case 0x03: /* WIDE DATA TRANSFER REQUEST */
 			        default:
-					/* Reject any unhandeled messages. */
+					/* Reject any unhandled messages. */
 
 					dev->sc_msg_out[0] = 0x07;
 					dev->sc_msg_out_len = 1;
@@ -1480,7 +1480,7 @@ sfas_postaction(struct sfas_softc *dev, 
 				break;
 
 			default:
-				/* Reject any unhandeled messages. */
+				/* Reject any unhandled messages. */
 
 				dev->sc_msg_out[0] = 0x07;
 				dev->sc_msg_out_len = 1;
@@ -780,8 +780,8 @@ sfas_setup_nexus(struct sfas_softc *dev,
 		/*
 		 * If the scsi unit is not set to synch transfer and we want
-		 * that, we have to negotiate. This should realy base the
-		 * period on the clock frequence rather than just check if
+		 * that, we have to negotiate. This should really base the
+		 * period on the clock frequency rather than just check if
 		 * >25 MHz
 		 */
